@@ -1,6 +1,6 @@
 package OpenResty;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.002001';
 
 use strict;
 use warnings;
@@ -541,7 +541,7 @@ OpenResty - General-purpose web service platform for web applications
 
 =head1 VERSION
 
-This document describes OpenResty 0.2.0 released on April 21, 2008.
+This document describes OpenResty 0.2.1 released on April 22, 2008.
 
 =head1 DESCRIPTION
 
@@ -562,11 +562,17 @@ And there're several (pure-client-side) web sites alreadying taking advantage of
 
 =over
 
-=item agentzh's blog site
+=item OpenResty's admin site
+
+L<http://resty.eeeeworks.org/admin/>
+
+=item agentzh's blog and EEEE Works' blog
 
 L<http://blog.agentzh.org>
 
-=item Yisou.com's BBS
+L<http://eeeeworks.org>
+
+=item Yisou BBS
 
 L<http://www.yisou.com/opi/post.html>
 
@@ -574,6 +580,10 @@ L<http://www.yisou.com/opi/post.html>
 
 This library is still in B<pre-alpha> stage and the API is still in flux. We're just following the "release early, releaes often" guideline. So please check back often ;)
 
+See L<OpenResty::Spec::Overview> for more detailed information.
+
+L<OpenResty::CheatSheet> also provides a good enough summary for the REST interface.
+
 =head1 INSTALLATION
 
 This is a basic guideline for settting up an OpenResty server on your own machine. Someone has succeeded in setting up one on Windows XP using ActivePerl 5.8.8. The normal development environment is Linux though. If you have any particular question, feel free to ask us by sending an email to the authors.
@@ -774,5 +784,5 @@ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLI
 
 =head1 SEE ALSO
 
-L<OpenResty::Spec::REST>, L<OpenResty::CheatSheet>, L<WWW::OpenResty>, L<WWW::OpenResty::Simple>.
+L<OpenResty::Spec::Overview>, L<OpenResty::Spec::REST>, L<OpenResty::CheatSheet>, L<WWW::OpenResty>, L<WWW::OpenResty::Simple>.
 
